Startup views (:mod:`cubicweb.web.views.startup`)
-------------------------------------------------
Usual selector: no_rset or yes.

Views that don't apply to a result set

*index*
    This view defines the home page of your application. It does not require
    a result set to apply to.

*schema*
    A view dedicated to the display of the schema of the instance

